                    WEDIT  Program  Documentation
                    =============================


                             Roland Waldi

                             Version 1.1


WEDIT is a field-oriented fullscreen editor and command line shell.

WEDIT 0.9 - Copyright (c) 1987 by Roland Waldi
WEDIT 1.0 - Copyright (c) 1990 by Roland Waldi
WEDIT 1.1 - Copyright (c) 1991 by Roland Waldi, all rights reserved.


ABOUT THIS DOCUMENT

This is a documentation of all features of WEDIT and the  accompanying
utilities. It is no user's guide or manual, although it is possible to
learn using WEDIT from the information given herein.

The escape character is replaced by  in this document, to allow
you to read it with a simple editor.

INTRODUCTION

The  editor  WEDIT  handles  text  files  with  lines  of  up  to  254
characters,  and  no  null character in any  line.  Longer  lines  are
automatically  split into 254-column lines during LOAD  or  GET.  Null
characters  are translated to blanks.  All other characters  are  dis-
played on the screen in the machine's standard character set graphics.

The  screen  is  divided into information  regions,  which  are  write
protected,  a  command  line to enter the editor commands as  well  as
'shell' commands for file manipulation and external program calls (2nd
line  on the screen),  20 data lines defining a window  74  characters
wide,  to display and edit the file,  and a bottom line to be used  as
notepad.  The last line on the screen is controlled by the  fullscreen
handler,  and shows a busy signal,  the current cursor  position,  and
some fullscreen flags described below.

Each  lines  of the file window are preceded by a line  number  field,
which may be overwritten with LINECOMMANDS.

The current line  used by many editor commands is the 10th data  line,
and is marked with an arrow (=>) after the line number.


CALL

WEDIT.PRG  is  a  program taking parameters.  The  parameter  line  in
general has the form:

filename0 filename1 filename2 comment ; commandline

It may be renamed to WEDIT.TTP, if no GEM programs will be called from
an editor session.  This saves ~7kB memory space.  When WEDIT  starts,
first  filename0   is  defined  as  the  current  filename.  Then  the
commandline  is executed,  then files filename0,  filename1  and file-
name2   are  loaded into the workfile 0,  1 and 2  into  storage,  and
finally  the  PROFILE.WEX  file  is executed,  if  it  exists  in  the
directory, from which WEDIT has been invoked, or in the root directory
at boot time.  If there are less than 3 filenames,  the  corresponding
workfiles remain empty. If no filename is given, WEDIT starts with all
workfiles empty.


FILES

Some extensions have a special meaning with WEDIT:  The extension .WEX
signals an executable file containing WEDIT commands,  .PAD is a  file
containing assignments for the numeric keypad keys,  and .BAK is  used
to  save an old file version,  when an edited file is written to  disk
with  a  SAVE command.  The file SAVE.$W$ is used as  default  put/get
file.


LIMITATIONS

WEDIT can handle

               up to 3 files edited in parallel

               file names of up to 63 characters (including drive and
                path;  the  only exception to this limit is the  ERASE
                command)

               up  to  254 characters per line  (256  characters  in-
                cluding CR and LF)

               up to 32766 lines per file

               file size only limited by free memory size

               up to 32766 lines in a copy buffer

               up  to  32766  lines in a  command  (WEX)  file,  with
                unlimited nesting

               up to 9 positional parameters in a WEX call (EXEC)

               up to 30 tab stops

               up to 64 commands saved for retrieval with RESHOW


WORKFILES

WEDIT  uses 3 workfiles.  Although they are basically treated  identi-
cally, there are some minor differences supporting their dedicated use
for some purposes.

workfiles 0,1   are for normal editing.  Special commands like  CMPARE
                operate  on  these files,  and they are  protected  by
                prompts against accidental overwriting.

workfile 2      is for display and editing of information, like direc-
                tory, command history, function key definitions. It is
                also  suited for compiler error listings,  display  of
                log files etc.  It is overwritten without warning by a
                LOAD command, which makes its use within command files
                fast,  but  also restricts its usefulness  for  normal
                editing.

workfile 3      is for command file (WEX file or programmable function
                key) execution. Since editing this file may be danger-
                ous for the unexperienced user,  it cannot be accessed
                by the WFILE command.  Never edit this workfile unless
                you are quite familiar with its use!


THE FULLSCREEN ENVIRONMENT

The  fullscreen environment is provided by the  FSIO  package.  During
input,  the  control is completely with this interface.  If  input  is
terminated by any of the enter or function keys,  control is  returned
to the editor, and the busy signal is shown.

The  screen is made up of 24 lines with 80 columns.  The 25th line  is
used as status line by FSIO, and shows (left to right):

FS              the FSIO indicator
---             terminal status: input mode
-X-                              busy, terminal locked
recording ...   buffer information during keypad key assignment
Aa              caps lock off: CAPITAL + small letters
AA                        on: only CAPITAL letters
S               SHIFT key pressed
C               CTRL key pressed
A               ALT key pressed
INSERT          insert mode on
ll cc           decimal value of cursor line and column
                (counted  1...24  and  -5...74).  The  column  counter
                offset  is  adjustable with  CTRL-keypad-+  and  CTRL-
                keypad--,   and   is  saved  in  the  PAD  file   (see
                "Key Assignment").
dd*ooo#hh       code of character under cursor (decimal, octal, hex)

The screen layout (shrinked horizontally to 70 columns instead of  80,
to fit on the paper) is:

0 path.and.filename                                 line : size / free
====> command-line
B12   T...:....1T...:...(2....:....3T...:....4)...:....5T...:....6....
..... this is the window top
..... >>> TOP OF FILE <<<
....1 text of line 1
....2 text of line 2
....3 etc
....4
....5
....6
....7
....8>this is the current line
....9
...10
...11
...12
...13
..... >>> END OF FILE <<<
.....
.....
.....
..... this is the window bottom
WEDIT version 1.1 Copyright .......bottom line          12.01.91 20:01

The  first  line  contains information  about  the  edited  file:  the
workfile  number (0,  1,  2 or 3),  the full name (including disk  and
path),  the  total number of lines,  the size in bytes,  and the  free
memory space in bytes.  Between the number of lines and the file size,
there is the change indicator, which is either a period (.) or a colon
(:).  The latter indicates, that the workfile has been changed and not
saved.  A  new file can only be loaded into workfile 0 or 1,  if  this
flag is off (= a period).  A workfile may be reset with the 'DELETE .'
command.  The whole line is protected,  i.e. it can not be overwritten
by the user.

The  second line is the command line,  where all editor  commands  are
entered. The commands are described in detail below.

The third line is an information line, which contains usually a ruler,
giving  the  column  position  of  the  file  window  below.   In  the
illustration above,  the column offset is zero,  i.e. the lines of the
file  are displayed from their starting column 1 to column 74 (on  the
reduced display above it is only to column 64).  The 'T' in this  line
mark  the  physical tab stops,  soft tab stops are marked by  't'  for
a  shifted window.  They may be redefined by the TABSET  command.  The
parentheses (...) in this line enclose the point/change region set  by
the  ZONE command.  If a non-empty copy buffer exists,  the number  of
lines  is  indicated  after  the letter B  at  the  beginning  of  the
information line.

Occasionally,  error messages and warnings are displayed in this line.
They may be cleared by pressing the Enter key. The information line is
also protected.

Lines  4 through 23 are the data window.  These 20 lines start with  a
line number field,  which may be overwritten with a linecommand. It is
followed  by  a  protected space,  which is changed to a  '>'  on  the
current line, and a data field of 74 columns. Pending linecommands are
displayed in the line number field.

The last line (24) is the bottom line, which at start always shows the
WEDIT  version in the left field (66 characters).  This field  may  be
used  as  a notepad for other data.  It can also be  modified  by  the
SETBOT  command.  The right field shows the date (dd.mm.yy)  and  time
(hh:mm) at the last Enter.


Keys

Cursor          up, down, right, left
                the cursor goes from line 24 to line 1 immediately.
CTRL SHFT Up    fast up (steps of 2)
CTRL SHFT Down  fast down (steps of 2)
CTRL SHFT Left  fast left (2 columns)
CTRL SHFT Rght  fast right (2 columns)
CTRL Left       left to start of word or start of space
CTRL Right      right to next word or space (advance one word)
Keypad )        advance to next unprotected field (field tab)
CTRL Keypad )   advance  cursor after the last nonblank  character  in
                the field, or to end of field
Keypad (        back  to  start of current field or  to  previous  un-
                protected field (field backtab)
Tab             right to next tab stop
SHFT Tab        left to next tab stop (backtab)
Home            cursor home to first unprotected field on screen
CTRL SHFT Home  (erase screen, do not use in WEDIT)
CR              assignable, default = SHFT CR (return)
SHFT CR         cursor to start of next line's first unprotected field
Del             delete one character, field shifted left
BS              delete character left of cursor, field shifted left
                does not cross field boundaries (backspace)
CTRL Del        delete to next word or space (delimited by blank)
ALT Del         delete whole field
Esc             delete to end of field
Ins             toggle  insert  mode on/off (insert  characters  in  a
                field)
CTRL Ins        insert mode on
ALT Esc         insert mode off
CapsLock        toggle caps-lock mode (only CAPITAL versus CAPITAL and
                small letters)
Undo            redisplay  screen as of last return to WEDIT  (logical
                clear)
CTRL Keypad +   column indicator offset +1
CTRL Keypad -   column indicator offset -1
Keypad /        define a sequence of keys (recording mode)
Keypad .        :\
Keypad 0        :\
...             :\
Keypad 9        : assignable keys
CTRL Keypad .   :/
CTRL Keypad 0   :/
...             :/
CTRL Keypad 9   :/
Keypad *        *
Keypad +        +
Keypad -        -
Help            assignable, default enter
SHFT Help       dto.
CTRL Help       assignable key
CTRL c          during execution of more than one  command:  interrupt
                execution before next command

Keys Returning to WEDIT

Enter           normal enter
F1 ... F10      function keys 1...10
SHFT F1 ...     function keys 11...20
CTRL F1 ...     function keys 21...30
SHFT CTRL F1... function keys 31...40
ALT F1...       function keys 41...50,  with arguments in the command-
                line
Help            same as Enter, if not reassigned

NOTE: The contents of the command line is ignored, when a programmable
function key (F1 ...  SHFT CTRL F10) is pressed.  It is stored in  the
reshow buffer,  and may be retrieved with the RESHOW command for later
use.  It is taken as parameter line for the keys (ALT F1 ... ALT F10).
To execute the command line, use either the ENTER key or the HELP key.


Mouse

Normal mouse movements will act as fast cursor key  repetitions,  i.e.
the cursor will be moved over the screen. The left mouse key acts as a
CTRL  RGHT (snap to next word),  the right mouse key acts as a  keypad
left parenthesis, i.e. a field backtab.


Line Mode

The fullscreen environment is left during prompting sequences. This is
indicated by a screen clear,  which also erases the fullscreen  status
line (25).

In line mode the LEFT and RIGHT cursor keys, the BS and DEL operate as
in fullscreen mode. In addition to usual input keys, the CR key can be
used to terminate input.  A line of text is cleared with the  CLR/HOME
or  the  UNDO key.  A blank is inserted with the INSRT  key.  The  ESC
operates similar to fullscreen mode, as an erase to end of line.


Key Assignment

To assign any of the assignable keys on the keypad (.,0,1,...,9),  the
Return-key  (CR) or the Help key,  press the keypad slash /  key.  The
status  line will now show "recording buffer" and the number of  empty
buffer locations. Any key pressed is now recorded in the buffer, until
one  of the assignable keys is pressed,  which automatically  finishes
the  sequence  and  assigns it to this key.  Each keypad  key  may  be
assigned twice,  with and without the control (CTRL) key pressed,  and
the Help key may be assigned different keystrokes for Help, SHIFT Help
and CTRL Help.  To delete an assignment,  use the same procedure,  but
press  the  assignable key to be reset immediately  after  the  keypad
slash.  The  key  will then return to its  usual  character  function.
Recording may be cancelled at any time by pressing the keypad slash  a
second time.

Assignments  may  be  saved and reloaded with  the  PAD  command  (see
below), together with the column counter offset.


TEXT INPUT

Text  may  be written or modified directly in the  data  window.  When
approaching  the end of line during writing,  or when text is  shifted
out to the right of the window,  a bell signal sounds. In insert mode,
only  text which existed before the last enter is still  intact,  when
shifted out at the right border.  In the display,  this text is  lost,
i.e. it may not be recalled by pressing the delete key! To delete with
restoring  the  invisible  text  correctly,  use  the  REMOVE  command
sequence as defined in the standard profile (CTRL-F2).


LINECOMMANDS

Linecommands may be entered in each line's number field (prefix area).
Optional numbers must be followed by a non-digit.  They are  evaluated
from  top  to  bottom.  Linecommands are always  executed  before  the
commandline (or function key command). No linecommands can be used, if
the prefix area is switched off.

A [n]                    insert copy buffer after this line n   times,
                         default is once, * means 1000 times

B [n]                    insert copy buffer before this line n  times,
                         default is once, * means 1000 times

                         The last A or B linecommand is pending, until
                         a  copy  buffer has been inserted  (from  the
                         next MOVE or COPY operation).

AA                       copy   the  copy  buffer  after   this   line
                         (for multiple copies)

                         This  linecommand is executed with  the  con-
                         tents  of  the copy buffer at  the  point  of
                         occurence during linecommand processing, i.e.
                         linecommands after this line will modify  the
                         copy buffer only after the copy.

C [n]                    copy  n  lines to the copy  buffer,  starting
                         from this line, default is 1 line, * = to end
                         of file

                         a negative n  marks a range upwards

CC                       delimits a copy block (all lines between  two
                         successive CC linecommands are copied to  the
                         copy buffer)

D [n]                    delete  n  lines,  starting from  this  line,
                         default is 1 line, * = to end of file

                         a negative number n  means deleting backward

DD                       delimits  a delete block (all  lines  between
                         two successive DD linecommands are deleted)

I [n]                    insert  n  lines after the current  line  for
                         input, default 1 line, * means 1000 lines

                         the  cursor is positioned to the first  input
                         line,  and the data window is shifted to  fit
                         as many of the new lines as possible

L                        locate: make this line the window top

LT                       locate and terminate find mode

M [n]                    move  n  lines to the copy  buffer,  starting
                         from this line, default is 1 line, * = to end
                         of file

                         a negative n  marks a range upwards

MM                       delimits a move block (all lines between  two
                         successive  MM linecommands are moved to  the
                         copy buffer)

O                        make  this  line  the overlay  line  for  all
                         following target linecommands

OD                       make this line the overlay line and delete it

P                        point: make this line the current line

                         The L or P linecommands must be used alterna-
                         tively, and on only one line.

PT                       point and terminate

R [n]                    repeat this line n  times,  default  once,  *
                         means 1000 times

RR                       delimits  a repeat block (all  lines  between
                         two  successive  RR linecommands  are  copied
                         after the last of these lines)

                         A  repeat block is repeated  only  once,  any
                         count given is ignored.

T [n]                    target line or group of n  target lines to be
                         underlayed ("or"ed) by the previously defined
                         overlay line

                         a negative n  marks a range upwards

TT                       delimits  a block of target lines (all  lines
                         between  two  succesive TT  linecommands  are
                         "or"ed  with the previously  defined  overlay
                         line)

X                        remove a pending linecommand ('A' or  pending
                         block)

*                        execute this line as a command line

                         The  * linecommand must be used on  only  one
                         line.  This line will be executed instead  of
                         the commandline. The commandline, however, is
                         saved  and  may be recalled  via  the  RESHOW
                         command for later execution.

#                        mark this line (one line for each workfile)

                         The marked line can be reached immediately by
                         the # command entered in the commandline.



COMMANDS

Commands may be entered in the command line.

Several commands may be entered at once, separated by a semicolon ';'.

An open brace '{' is initially defined as comment character,  and ends
any command line.  Text beyond the { is ignored. The comment character
may be redefined by the COMMENTCHAR command.

All  commands may be abbreviated to a minimum of characters  indicated
by capital letters. Parameters in brackets [] are optional.

Several  commands have a default parameter,  which is  used,  when  an
optional  parameter  is omitted. Also an asterisk * may be  a  special
parameter for some commands.

Commands may also be executed from a command file,  with extension WEX
(called  WEX  file below).  Only 74 characters per line may  be  used,
which is the same number as fits into the screen command line.

Many  commands  operate on a range of several  lines.  This  range  is
calculated from and including the current line. This means -2 includes
the current line and one line before it,  5 includes the current  line
and 4 lines after it etc.  If the current line is the 'TOP OF FILE' or
'END OF FILE' line,  it is included in counting, but not in execution,
i.e. a line count of 5 in the top line includes lines 1 through 4.


General Commands

{                        comment, may be redefined by:

COMMEntchar [c]          define c  as new comment character

                         if c  is omitted, the current comment charac-
                         ter is displayed

                         NOTE:  Do  not change the  comment  character
                         under any circumstances!  But if you do, make
                         sure that the old one is not used in any  WEX
                         files or programmed function keys.

PREfix [on|off]          switch the prefix (linenumber) area on or off

                         default is on

                         the prefix area is also switched on when  the
                         workfile is changed

Reshow                   show last command line

                         Up  to 64 commandlines are saved and  may  be
                         reviewed by successive RESHOW  commands.  The
                         cursor  is  positioned  at the  end  of  this
                         command line, unless it is in the file region
                         or it is set by the CURSOR command.

                         Any  commands after RESHOW in  a  commandline
                         are ignored.

                         RESHOW as the last command in a multicommand-
                         line  makes this line permanently staying  on
                         the screen

RReshow                  reverse  RESHOW:   go  backwards  in  command
                         buffer

                         This  command may be used in connection  with
                         successive  RESHOW commands to review in  the
                         opposite direction

                         Any  commands after RRESHOW in a  commandline
                         are ignored.

=                        execute  last  command once more  (only  last
                         command, not last command line!)

                         Any  commands  after = in a  commandline  are
                         ignored

QUit                     leave editor

                         If there are still some changes in workfile 0
                         or 1 unsaved,  QUIT will refuse to  stop.  If
                         you want to quit anyhow, use QQUIT.

QQuit                    quick quit, leave editor without saving

PFkey [n] [commandline]  define  a programmable function key (n   =  1
                         ... 64) as commandline

                         no number n  or * defines key F10

                         commandline   may be at most  71  characters,
                         and  is eventually truncated to that  without
                         warning

                         for  keys 41...64 arguments may be  given  in
                         the commandline;  keys 51...64 are not acces-
                         sible  via real keys,  only via  the  EXECUTE
                         command or via synonyms

EXecute [filename [parameter1 ... parameter9]]
filename [parameter1 ... parameter9]
                         execute   commands  in   file   filename.WEX,
                         default * (current workfile).

                         filename   may include a  complete  path,  if
                         given with EXECUTE

                         if  filename  is *,  the current workfile  is
                         executed;  if this is 3,  execution starts at
                         the line following the current line.

                         if filename  is a number in the range 1...64,
                         the  function of the  corresponding  function
                         key  is  executed  (only if  EXECUTE  is  not
                         omitted)

                         all occurrences of the escape character  fol-
                         lowed  immediately by a digit 1 through 9  in
                         the  WEX  file will be substituted  with  the
                         parameter1   through parameter9   immediately
                         upon invocation

                         parameters  are  either  words  delimited  by
                         blanks or a string enclosed in apostrophes or
                         a hexadecimal string x'...',  as described in
                         the  chapter  "Editing   Commands:   Finding"
                         below, with a maximum of 64 characters

                         if a parameter is a single question mark (?),
                         the actual parameter string will be  prompted
                         or read from the next line within a WEX  file
                         (at most 79 characters)

                         the  last parameter may be delimited  by  the
                         separator  or  comment  character  without  a
                         blank in between

                         all occurrences of the escape character  fol-
                         lowed  immediately by the character  'F'  are
                         replaced  with the full path/filename of  the
                         active workfile, escape 'f' with the stripped
                         filename  (without  drive/path),  escape  'n'
                         with  the  first part  of  it  (i.e.  without
                         extension),  escape  't' with the  file  type
                         (extension),  escape 'P' with the file  path,
                         escape 'p' with the current path  (terminated
                         with  '\'),  escape  'w'  with  the  workfile
                         number  and escape 'c' with the current  con-
                         trol  path,   immediately  upon   invocation,
                         escape  'd'  with  the current  date  in  the
                         format  'dd.mm.yy',  and escape 'x' with  the
                         value of the top of the calculator stack

                         Example: for file C:\WORK\COMMANDS.HLP
                         F is         C:\WORK\COMMANDS.HLP
                         P is         C:\WORK\
                         f is         COMMANDS.HLP
                         n is         COMMANDS
                         t is         HLP

                         c may be     C:\WEDIT\
                         w may be     1
                         p may be     C:\
                         d may be      9.12.88
                         x may be     -155789

                         Recursive  use  of  the  escape-sequences  is
                         possible; the evaluation sequence is 1-2-3-4-
                         5-6-7-8-9-f-n-t-F-P-c-p-w-d-x.

                         NOTE:  Any  data in the copy buffer  will  be
                         erased at the start of a WEX file execution.

                         EXECUTE commands may occur within WEX  files,
                         the  only limit being available  buffer  size
                         (the files are read completely before  execu-
                         tion).

                         Only the first 75 characters in each line  of
                         a WEX file are used as command line.  Parame-
                         ter substitution resulting in lines with more
                         than  75 characters may result  in  incorrect
                         operation.

                         During execution fullscreen mode is  switched
                         off  as  soon as writing to the  terminal  is
                         expected.  It is switched on again only after
                         all  commands of the WEX file plus  all  com-
                         mands  following the EXECUTE in the  command-
                         line have been executed.

                         Execution may be stopped between commands  by
                         pressing  CTRL-C (^C).  It may be resumed  at
                         the next command by pressing ENTER after  the
                         prompt.

                         While debugging WEX files,  use the statement
                         'WFILE  3'  after the 'EXECUTE  ...'  in  the
                         commandline.

EXECWfw                  acts  like 'EXECUTE *' in  workfile  3,  i.e.
                         continue execution after substituting  escape
                         sequences

                         This may be useful,  after the escape charac-
                         ter  has  been changed,  to  substitute  some
                         arguments only later in the  execution,  like
                         in the following example:

                         LOAD 1; ESCAPECHAR &
                         ERASE &P&n.BA2
                         RENAME &P&n.BA1 &P*.BA2
                         RENAME &F &P*.BA1; ESCAPECHAR 

                         This  four-line  WEX file will first  load  a
                         file,   then  delete  backup2,  make  backup1
                         backup2,  and the current file backup1,  thus
                         retaining always three generations of a file.
                         The substitutions of the file's path '&P' can
                         be  done  correctly only after the  file  has
                         been loaded.

GO n                     advance n lines in workfile 3

                         n  is a positive or negative number

                         Loops  or simple branches may  be  programmed
                         with  this  command.  In contrast to  a  real
                         'goto',  only  the command file  position  is
                         changed;  commands  following  the GO  on the
                         same line are not skipped!

SYNonym n [name]         defines a synonym for function key n

                         name  is a string of not more than 7  charac-
                         ters

                         The  function  key may thus be  called  as  a
                         command,   with  parameter  substitution   as
                         mentioned  above.  Note  that  function  keys
                         41...50  (ALT-F1...ALT-F10) may be used  with
                         parameters in the commandline directly; func-
                         tion  keys  51...64 are accessible  only  via
                         'EXECUTE  n   ' or a  synonym.  If  name   is
                         omitted, the synonym is cleared.

EXECLine                 execute current line as commandline

                         In  contrast to the  EXECUTE  command,  full-
                         screen is not turned off during EXECLINE.

CAll filename [parameterstring]
@filename [parameterstring]
                         call   program  filename    with   parameters
                         parameterstring

                         if parameterstring  contains blanks,  it must
                         be included in apostrophes ',  an  apostrophy
                         within  such a parameterstring must be  coded
                         as ''

                         if parameterstring  is a single question mark
                         (?),  the  actual  parameter string  will  be
                         prompted for,  which allows up to 79  charac-
                         ters;  within a WEX file,  the next line will
                         be  used,  which allows up to 126  characters
                         for  parameterstring;    in  both  cases  the
                         string must not be enclosed in apostrophes

                         filename    may  include  device   and   path
                         informations.   If  no  extension  is  given,
                         ".TOS"   will   be  assumed  for   an   empty
                         parameterstring  and ".TTP" otherwise.

                         NOTE:  GEM  applications may be  called  from
                         WEDIT.PRG,   if   they  take  care  for   GEM
                         initialization.

                         If a CALL returns with a non-zero  returncode
                         within a WEX file execution, the user will be
                         prompted to allow interrupting the EXEC  with
                         CTRL-C.

                         WARNING: Never call programs which stay resi-
                         dent  in memory;  they will be  destroyed  by
                         subsequent editing!

CPAth [path]             define  an  alternate path   to  be  searched
                         after   the  current  path  for  WEX   files,
                         programs invoked by CALL and PAD files

                         the  initial setting is C:\,  if the C  drive
                         exists, or A:\ otherwise

                         path  must be at most 59 characters,  includ-
                         ing  a terminating backslash (which is  added
                         internally, if you omit it)

Query [type]             get informations,  either in the message line
                         or in workfile 2

                         information  in message  line,  depending  on
                         type:

                         Size           display file size in bytes

                         SPace [d]      display file size, free memory
                                        workspace and free disk  space
                                        on drive d  (in B and KB,  the
                                        default drive if omitted).

                         overwrite workfile 2, depending on type:

                         PFkeys         create  PFKEYS.WEX  with   the
                                        current  function key  defini-
                                        tions.
                         STatus         create  STATUS.WEX  with   the
                                        current control characters and
                                        parameter  settings  [this  is
                                        the default].
                         Reshow         create  RESHOW.WEX  with   the
                                        last 64 commands.

FName [filename]         change the filename for the current  workfile
                         to filename

                         filename  may contain wildcards '?' and  '*',
                         which are resolved from the current filename

WAIt                     wait  for a key (to be used by WEX  files  to
                         avoid flushing messages)

BELl                     sound bell

Setbot [text]            write text  into bottom line

                         default  is the WEDIT version  and  copyright
                         text;  a single * for text  means the current
                         line number (to be used in WEX files)


Screen Commands

CURsor [[:]n [c]]        put cursor to current line plus n,  column c,
                         or to line number :n, column c

                         default is the current line, column 1

                         *  for  n  means the current line,  0  for  n
                         means the command line (no file line at all)

                         *  for c  means the position after  the  last
                         character in the line (you can find  trailing
                         blanks with this command)

TAbset [n1 [n2 ...]]     set  tab  stops in the  current  workfile  on
                         fixed screen positions,  defined by the  file
                         columns n1, n2, ... n30

                         A  value of 0 is the last tab stop.  'TA'  or
                         'TABSET 0' resets all tab stops,  except  one
                         at column 1.  An asterisk (*) for n1  defines
                         the default setting,  'TABS 1 9 17 25 33 ...'
                         each  8  columns from the  previous  one.  An
                         asterisk at any other position advances by  8
                         characters,  i.e. 'TABS 1 6 * * *' is equiva-
                         lent to 'TABS 1 6 14 22 30'.

                         Tab stops beyond column 74 may be set for use
                         with the TABEXPAND command (soft tab  stops).
                         They  are ignored by the terminal  TAB  func-
                         tion.

                         Physical tab stops are always the  same,  and
                         are  calculated  assuming PREFIX ON  and  the
                         leftmost text column being column 1,  i.e. ni
                         = 1 means physical column position 6 etc.

                         Tab stops are defined for workfiles 0,  1 and
                         2  separately.  Tab stops in workfile  3  are
                         always the same as in workfile 2.

INVert                   invert screen colour

CLICk [s [delay [rate]]] set key click:  s  = ON, OFF or 1, 0, and key
                         repeat  delay   and rate  in  units  of  1/50
                         second

                         if s is omitted, toggle key click

                         default  are  the  current  delay   and  rate
                         values;  * means delay  14 and rate  2 (0.28s
                         and 25 Hz)

                         NOTE:  other  numbers  for s   are  possible.
                         CLICK 2 enables repeat mode,  CLICK 4 enables
                         the bell signal,  any sum of 1,  2, 4 enables
                         the combination of key click, repeat or bell.
                         To switch any off again,  use -1,  -2 and  -4
                         (which   actually  toggles  the   appropriate
                         flag).

PAd [action [filename]]  depending  on  action,  save or  load  keypad
                         assignments   in/from   file    filename.PAD,
                         default is DEFAULT.PAD

                         filename  may include a complete path

                         action:
                         Save           save to file
                         Load           load from file


File Handling Commands

DIR [path [Insert]]      overwrite workfile 2 with directory  informa-
                         tion  for path,  default *.* (in the  current
                         path)

                         the filename for workfile 2 is set to DIR.WEX

                         if the parameter INSERT is used, the workfile
                         will  not  be  cleared,   and  the  directory
                         information  is  inserted at the top  of  the
                         workfile

                         NOTE:  You  may insert commands like LOAD  or
                         ERASE and execute the file with the  'EXECUTE
                         *' command, or save it for later execution.

PATH [path]
CDir [path]              set the default path to path,  which defaults
                         to the current path of the current disk drive

                         A  path may be given with or without a  drive
                         identifier  (examples  are   A:;   B:\mydir\;
                         \dir\subdir)

                         If path  is ..  the new path will be one step
                         below in the hierarchy (e.g.  if current path
                         is B:\MYDIR\SUBDIR\,  after 'PATH ..' it will
                         be B:\MYDIR, after another 'PATH ..' B:\)

                         If  path   is omitted,  the current  path  is
                         displayed in the message line. Otherwise, the
                         new current path is displayed in the  message
                         line, unless an error message is pending.

LOad [filename [a [z]]]  read  a file (completely or partly) into  the
                         editing buffer of the current workfile

                         filename   may  be any valid filename  for  a
                         GEMDOS file search. If the volume is omitted,
                         the current default volume is used. If no '\'
                         is  contained,  the current path  is  substi-
                         tuted. If wildcards '*' and '?' are used, the
                         first file matching is used.  If no  filename
                         is given, the default filename of the current
                         workfile will be used.

                         a  is the first record read, z  the last, for
                         a file to be loaded only partly

                         Any  parts of a file not loaded will be  lost
                         at  a subsequent SAVE!  To edit big files  in
                         parts,  each  part  has to be saved  using  a
                         different  name,  and  all parts have  to  be
                         merged afterwards by a copying program  (e.g.
                         FCOPY with option a).  The file size given in
                         the  display is the size of the  whole  file.
                         The unloaded size is obtained after  deleting
                         the edited part with 'DELETE .'.

                         Before LOADing,  the current workfile must be
                         either empty,  or not changed after the  last
                         LOAD  or  SAVE.  In the latter  case,  it  is
                         replaced with the loaded file.

SAVe [filename]          save file to filename,  rename existing  file
                         to filename.BAK

                         default  is  the current  filename  (name  of
                         loaded file)

                         if  only  a  path  is  given,   the   current
                         workfile's filename will be appended

                         if wildcards are used,  they will be expanded
                         with the current workfile's filename

SSAve [filename]         save file to filename  without backup

                         default  is  the current  filename  (name  of
                         loaded file)

                         if  only  a  path  is  given,   the   current
                         workfile's filename will be appended

                         if wildcards are used,  they will be expanded
                         with the current workfile's filename

                         Do not use PRT:,  AUX:  or CON:  with SAVE or
                         SSAVE.  To send the file to these ports,  use
                         'PUT . PRT:' etc.

PUT [[:]n [filename]]    write n  lines starting with the current line
                         at the end of file filename,  default 1 line,
                         * = to EOF, .  means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are appended to the file

                         if  no  filename  is  given,  the  lines  are
                         appended to a default put/get file

                         the names PRT: or AUX: for filename  send the
                         specified  lines  to the printer   or  serial
                         port, CON: displays them in scrolling mode on
                         the screen (pause with ^S, continue with ^Q)

                         NOTE:  Use  SSAVE to replace a file with  all
                         data,  and PUT . to append it to an  existing
                         file.

PUTD [[:]n [filename]]   write n  lines starting with the current line
                         at  the  end of file  filename,   and  delete
                         these lines in the workfile

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are appended to the file

                         if  no  filename  is  given,  the  lines  are
                         appended to a default put/get file.

SENd [filename [string]] write  string  to the end of file  or  device
                         filename,  default is a NUL character

                         the names PRT: or AUX: for filename  send the
                         character  string to the printer   or  serial
                         port (modem),  CON:  to the screen (e.g. con-
                         trol characters).

                         If string  is a single '?',  a string will be
                         prompted or taken from the next line of a WEX
                         file.

Get [filename [a [z]]]   insert  lines a  through z  of file  filename
                         after the current line

                         if no filename  is given,  the whole  default
                         put/get file is inserted

                         if  a  path  name  terminated  with  \  or  a
                         filename with wildcards is given,  it will be
                         completed from the current file name

                         NOTE:  The copy buffer is deleted after a GET
                         command.

RESET                    clear  editor buffer (all workfiles  are  de-
                         leted, tab stops and zones are reset)

ERAse [filename]         erase file filename

                         if  no  filename   is  given,  the  currently
                         edited file is erased

                         the user is prompted to confirm the deletion,
                         unless the full command name 'ERASE' is used

                         Wildcards * (for any piece of the filename or
                         filetype) and ? (for one arbitrary character)
                         may be used to delete several files at once.

                         An empty subdirectory (folder) is deleted, if
                         filename  terminates with a backslash \

REName filea fileb       rename filea  to fileb

                         if  filea  contains wildcards,  all  matching
                         files will be renamed

                         if  fileb  contains wildcards,  they will  be
                         expanded  from  the  original  file  name;  a
                         single question mark '?' will cause prompting
                         of the second name

                         Rename  may include changing  folders  within
                         the same device.

MDir pathname            make  a new subdirectory  (folder)  pathname,
                         which must not terminate with a \


Editing Commands: Moving Around

Wfile [n]                switch to workfile n  (0,  1 or 2), default 1
                         if current workfile is 0 or 0 otherwise,  * =
                         0

                         NOTE:  Workfile 2 may be overwritten by  some
                         editor commands,  and no warning is given, if
                         it  is  unsaved  at QUIT.  Use  it  only  for
                         temporary data, which need not to be saved.

PCursor                  point cursor:  make the line where the cursor
                         is currently the current line

                         if  the  cursor is not in a  file  line,  the
                         current line is not changed

:[n]                     make line n  the current line, default 1, * =
                         bottom line (end of file)

-[n]
Up [n]                   go up n  lines, default 1, * = to top

+[n]
Next [n]
Down [n]                 go down n  lines, default 1, * = to bottom

                         This is the same as 'UP -n '.

TOP                      go to top of file

Bottom                   go to bottom of file

MArk                     mark current line (same as # linecommand)

FLip#                    mark current line and go to previously marked
                         line, i.e. flip between two marked lines

#                        go to marked line (with # linecommand or MARK
                         or FLIP# commands)

RIght [n]                shift window n  columns to the right, default
                         1, * = 74

                         A negative n  shifts to the left.

LEft [n]                 shift window n  columns to the left,  default
                         1, * = 74

RIGHTLeft [n]            same as 'RIGHT n ',  if window is  unshifted,
                         'LEFT n ' otherwise, default 40, * = 74


Editing Commands: Finding

A string is either a sequence of characters delimited by blanks or end
of line,  which does not include blanks,  or a sequence of  characters
delimited by quotes '.  In the latter case,  a quote within the string
must  be  typed as ''.  A third possibility is a  hexadecimal  string,
which  is generally written as x'...' or X'...',  where  ...  are  any
number  of  pairs of hexadecimal digits 0-9,  A-F or  a-f.  Any  other
character  terminates  the string and may be interpreted as  the  next
parameter.

Point [string [op string] [mode]]
                         make  next occurrence of string   within  the
                         current  column zone after the  current  line
                         the new current line

                         string    may  contain  wildcards,   and   is
                         restricted to 73 characters in total

                         a second string  may be given after a logical
                         operator op,  which may be '|' for OR or  '\'
                         for ANDNOT

                         mode  is the search mode:
                         Ignore       = ignore upper- / lowercase
                         Respect      = (default)  respect  upper-   /
                                        lowercase
                         Variable     = search  for  string  with   no
                                        adjacent letter (no  wildcards
                                        are allowed in this mode)

                         if string  is omitted, or a single asterisk *
                         is given, the string of the last FIND, POINT,
                         / or LOCATE command is used

                         The  end of line or zone is treated as  space
                         in the search, so P 'A ' will also find lines
                         ending with the character A,  or any A at the
                         end of the search zone.

                         At end of file,  the search continues at  the
                         top  of  file,  and a  message  "wrapped"  is
                         displayed.

                         If the string is not found,  or the file  has
                         been wrapped,  the rest of the commandline is
                         ignored.  This part is redisplayed,  in order
                         to have it executed by simply pressing ENTER.

                         NOTE:  the  current line may have changed  by
                         fullscreen line inserts / deletes, before the
                         search starts.

/...                     acts like POINT '...' RESPECT, all characters
                         after / being taken as pointstring

CPOint [string [op string] [mode]]
                         acts as POINT string mode  and the cursor  is
                         positioned  at  the beginning of  the  string
                         found

RPoint [string [op string] [mode]]
                         reverse point:  same as POINT,  but  searches
                         backwards

-/...                    acts like RPOINT '...' RESPECT,  all  charac-
                         ters after / being taken as pointstring

NPoint [string [op string] [mode]]
                         not-point:  make  next  line  not  containing
                         string   within the current column  zone  the
                         current line

RNPoint [string [op string] [mode]]
NRPoint [string [op string] [mode]]
                         reverse not-point: make next line previous to
                         current line,  which does not contain  string
                         in the current column zone, the current line

Locate [string [op string] [mode]]
                         make  next  occurrence  of  string    (within
                         zone)  after  the  window top  line  the  new
                         window top

                         string    may  contain  wildcards,   and   is
                         restricted to 73 characters in total

                         a second string  may be given after a logical
                         operator op,  which may be '|' for OR or  '\'
                         for ANDNOT

                         mode  is the same as for the POINT command

                         if string  is omitted, or a single asterisk *
                         is given, the string of the last FIND, POINT,
                         / or LOCATE command is used

                         At end of file,  the search continues at  the
                         top  of  file,  and a  message  "wrapped"  is
                         displayed.

RLocate [string [op string] [mode]]
                         same as LOCATE, but searches backwards

Find [string [op string] [mode]]
ALL [string [op string] [mode]]
                         start  find  mode:  display only  lines  with
                         string  within the current column zone

                         string    may  contain  wildcards,   and   is
                         restricted to 73 characters in total

                         a second string  may be given after a logical
                         operator op,  which may be '|' for OR or  '\'
                         for ANDNOT

                         mode  is the search mode:
                         Ignore       = ignore upper- / lowercase
                         Respect      = (default)  respect  upper-   /
                                        lowercase
                         Variable     = search  for  string  with   no
                                        adjacent letter (no  wildcards
                                        are allowed in this mode)

                         if string  is omitted, or a single asterisk *
                         is given, the string of the last FIND, POINT,
                         / or LOCATE command is used

                         The  end of line or zone is treated as  space
                         in the search, so F 'A ' will also find lines
                         ending with the character A,  or any A at the
                         end of the search zone.

NFind [string [op string] [mode]]
EXCLude [string [op string] [mode]]
                         start nfind mode:  display only lines,  which
                         do  not  contain string  within  the  current
                         column zone

                         the arguments are the same as for FIND

Terminate                terminate find or nfind mode

                         if  not in find mode,  an error code of 1  is
                         set

CMAtch                   find  matching ({[<` '>]}) to  the  character
                         under  the cursor;  the current line will  be
                         the  line with the  matching  character,  the
                         cursor is on this character

WILDcard [c]             define new wildcard character c

                         if c  is omitted,  the current wildcard char-
                         acter is displayed

CASe [mode]              set default mode  for POINT/LOCATE

Zone [c1 [c2]]           define a column zone for searching and chang-
                         ing, from column c1  to column c2, default is
                         the 1 for c1  and 254 for c2

                         * for c1  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         * for c2 means to end of line,  which is also
                         the default.

                         if c2  is preceded by a '+' sign,  c1+c2   is
                         used as second column

CMPare                   compare workfiles 0 and 1,  and stop at first
                         different line

                         Comparison  starts  at the current  lines  of
                         both  workfiles.  This  command may  only  be
                         invoked  while  workfile  0  is  edited  (use
                         'WFILE 0' to edit workfile 0).

Editing Commands: Text Changing

All changing commands start from the (included) current line. A string
is a character or hexadecimal string as defined in the last chapter.

CDELete [[:]n [c1 [[+]c2]]]
                         delete columns c1 through c2 in n  lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n, the change
                         is  extended  from the current  line  to  the
                         marked  line  (with  #  linecommand  or  MARK
                         command)

                         * for c1  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         * for c2 means to end of line.

                         if c2  is preceded by a '+' sign,  c1+c2   is
                         used as second column

                         If omitted, n  and c1 default to 1, and c2 to
                         c1.

TRUncate [[:]n]          remove trailing blanks from n  lines, default
                         1, * = to EOF, . means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are truncated

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         truncated

TRIm [[:]n [m]]          trim n  lines to maximum length m,  default 1
                         line, * = to EOF, . means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are trimmed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         trimmed

                         m   is the maximum number of characters in  a
                         line, default is the last column displayed in
                         the data window, * means 254

                         Linebreaks are at the last blank,  except  if
                         there is no blank in a line. The reformatting
                         done by the trim command will split or  merge
                         lines  as required to get a  maximum  filling
                         with  at  most m  characters,  until  a  line
                         starting  with  a blank or an empty  line  is
                         found. There reformatting starts again. Trai-
                         ling blanks are removed.

                         This command has some side effects:

                         If  a marked line (#),  pending block or  'A'
                         linecommand  points  to  a  line  within  the
                         trimmed  area,  this will point to the  first
                         line of the trimmed area afterwards.  A  non-
                         empty  copy  buffer  is  copied  before   the
                         trimmed  area.  The current line is the  last
                         line of the trimmed area.

UNDoubl [[:]n [c]]       delete subsequent lines, which are equal from
                         column c  to the end

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are considered;  *  means
                         to EOF, . means all lines

                         if  a hash # is coded instead  of  n,  double
                         lines  are removed from the current  line  to
                         the  marked line (with # linecommand or  MARK
                         command)

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'. Default is 1 for the whole lines.

                         Lines  with less than c  columns are  consid-
                         ered equal.  Lines with different numbers  of
                         trailing blanks are not considered equal.

TABEXpand [[:]n [c]]     expand all tab characters c  (default is  $09
                         =  \011  =  TAB) to the tab  stops  set  with
                         TABSET for the current workfile in n  lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are expanded

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         expanded

                         Tab stops are counted from the beginning of a
                         line,  independent  of  the position  of  the
                         window.   The   positions   marked   in   the
                         information  line are only  correct,  if  the
                         leftmost column displayed is column 1 of  the
                         file records.

CInsert [[:]n [c]] [string|*]
                         insert  string   starting at column c   in  n
                         lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         * for string  means,  that the copy buffer is
                         inserted line after line

                         If  there are more lines in the  copy  buffer
                         than defined by the line range, the remaining
                         lines stay in the copy buffer.  If there  are
                         less lines, the excess lines are not altered,
                         but the whole copy buffer is kept.

                         If omitted,  n  defaults to 1,  c to  0,  and
                         string to ' '.

NUmber [[:]n [c [start]]]
                         insert the line number (5 digits) starting at
                         column c  in n  lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         If omitted, n  and c  default to 1.

                         start  can be used to define the first number
                         different from the current line number.

CDUpl [[:]n [c1 [[+]c2 [c3]]]
                         duplicate  text  in columns  c1  through  c2,
                         insert it at column c3 in n  lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         defaults are column 1 for c1,  the same as c1
                         for c2, and the next after c2 for c3

                         * for c1  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         *  means end of line for c2 and for c3

                         if c2  is preceded by a '+' sign,  c1+c2   is
                         used as second column

APpend [[:]n] string     append string  to n  lines, default 1, * = to
                         EOF

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         if string  is a single question mark (?),  it
                         will be prompted from input (up to 79 charac-
                         ters) or read from the next line within a WEX
                         file (up to 254 characters)

OVerlay [[:]n [c [string|*]]]
                         overlay  string  starting at column c   in  n
                         lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         * for string  means,  that the copy buffer is
                         overlaid line after line

                         If omitted,  n  defaults to 1,  c to  0,  and
                         string to ' '.

OR [[:]n [c [string]]]   underlay  string   (replace blanks  with  the
                         corresponding characters) starting at  column
                         c  in n  lines

                         default is 1 line,  * means to EOF,  .  means
                         all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         If omitted,  n  defaults to 1,  c to  0,  and
                         string  to the overlay string defined by  the
                         last O linecommand.

UPPercase [[:]n]         translate  all lowercase letters  within  the
                         column zone (defined by the ZONE command)  in
                         n   lines to uppercase letters,  default 1  1
                         line, * means to EOF, . means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

LOWercase [[:]n]         translate  all uppercase letters  within  the
                         column zone in n  lines to lowercase letters,
                         default 1 line, default is 1 line, * means to
                         EOF, .  means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         changed

Change string1 string2 [[:]n [[-]m [mode]]]
                         change  string1  to string2  (any one may  be
                         the  nulstring  ''),  in n  lines at  most  m
                         times  per  line,  but only  if  string1   is
                         within  the column zone defined by  the  ZONE
                         command

                         default is 1 line,  * means to EOF,  .  means
                         all lines, :n  = to line n, # to marked line

                         m  defaults to 254

                         if  m  is preceded by a minus sign  '-',  the
                         changed  part of a line is subject to  subse-
                         quent changes,  otherwise only the  remaining
                         part of the line will be used

                         This is illustrated by the following example:
                         '------'
                         is changed by 'CHANGE -- - 1 99' into
                         '---'
                         i.e. three consecutive strings '--' are chan-
                         ged to '-'.  The command 'CHANGE -- - 1  -99'
                         would have changed it to
                         '-'
                         since  after the first change  '-----'  would
                         still start with '--' and so forth.

                         mode  is the search mode for the first string
                         Ignore       = ignore upper- / lowercase
                         Respect      = (default)  respect  upper-   /
                                        lowercase
                         Variable     = search  for  string  with   no
                                        adjacent letter

                         If string2  is a single question mark (?), it
                         will  be prompted or read from the next  line
                         withing a WEX file (up to 79 characters).  If
                         it should be the text "?",  use single quotes
                         ('?').

                         The  end of line is treated as space  in  the
                         search for string1,   so C 'A ' 'X' will also
                         change  lines ending with the character A  to
                         those ending with X.

                         NOTE:  the  current line may have changed  by
                         fullscreen line inserts / deletes, before the
                         change search starts.

SPLtjoin [c]             split line with cursor at column c  or,  if c
                         is  after  the  last  character,   join  with
                         subsequent line

                         *  for c  means the position of  the  cursor.
                         '*+c'  or  '*-c'  may be  used  to  define  a
                         position relative to '*'.  If c  is  omitted,
                         column 1 is assumed.


Editing Commands: Line Changing

All changing commands start from the (included) current line.

Insert text              insert one line after the current line,  with
                         text

                         If no text is given, the cursor is positioned
                         at the beginning of this line.  The new  line
                         will be current line.

Add [n] [string]         insert n  lines after the current line,  with
                         text string

                         if string  is a single question mark (?),  it
                         will be prompted from input (up to 79 charac-
                         ters) or read from the next line within a WEX
                         file (up to 254 characters)

DELete [[:]n]            delete n  lines,  default is 1 line,  * means
                         to EOF, .  means all lines (empty workfile)

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are deleted

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         deleted

Move [[:]n]              move n  lines to the copy buffer,  default 1,
                         * = to EOF, .  means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are moved

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         moved

                         The  lines are appended to the  copy  buffer,
                         until it is inserted or reset.  The  contents
                         of the copy buffer can be inserted using  the
                         A or B linecommand.

COPy [[:]n]              copy n  lines to the copy buffer,  default is
                         1 line, * means to EOF, .  means all lines

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are copied

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         copied

                         The  lines are appended to the  copy  buffer,
                         until it is inserted or reset.  The  contents
                         of the copy buffer can be inserted using  the
                         A or B linecommand,  or used with CINSERT  or
                         OVERLAY.

AFTer                    move copy buffer after current line

                         the copy buffer is reset by this command

BRESet                   reset the copy buffer (data are deleted)

SOrt [:]n [mode] [a1 [z1 [a2 z2 ...]]]
                         sort n  lines beginning with the current line
                         (* = to EOF,  .  = all lines) using up to  10
                         fields limited by columns a1 to z1,  a2 to z2
                         ...

                         if n  is preceded by a colon :,  lines up  to
                         (including) line n  are changed

                         if a hash # is coded instead of n,  all lines
                         from the current line to the marked line  are
                         sorted

                         the column ranges a1 to z1,  a2 to z2 ... can
                         be  coded as * or with sign as described  for
                         the CDELETE command

                         mode  is the sort mode:
                         Asc  = (default) ascending ASCII order
                         Desc = descending ASCII order
                         *    = lexicographically, i.e. aAbB...

                         'TOP; SORT *' will sort the whole file, using
                         the whole line.


Block Commands

Block  commands are used to handle a column block.  A column block  is
defined  by  an upper left corner (command BBEGIN) and a  lower  right
corner  (command BEND),  or a lower left corner (BBEGIN) and an  upper
right  corner (BEND).  If the column defined by BBEGIN is  after  that
defined by BEND, this defines always an empty block!

The  column block boundaries remain fixed and defined until  they  are
redefined by BBEGIN or BEND.  They are the same in all workfiles, i.e.
only  one  set of boundaries is used,  and also remain  fixed  if  the
contents are changed or moved.

BBegin [l [c]]           define  the  upper left corner  of  a  column
                         block to be line l  and column c

                         *  for l  means the current  line,  which  is
                         also the default

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'. The default for c  is column 0.

BEnd [l [c]]             define  the  lower right corner of  a  column
                         block to be line l  and column c

                         *  for l  means the current  line,  which  is
                         also the default

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'. The default for c  is column 0.

BCopy                    copy the column block to the copy buffer

                         The copy buffer may be inserted,  overlaid or
                         added as new lines with the CINSERT,  OVERLAY
                         or AFTER command or A, AA or B linecommands.

BDELete                  delete the column block


Calculator Commands

Simple 32-bit integer calculating including data from the workfile  is
possible  within the WEDIT command set.  An 8-register-stack  (x0...x7
FIFO)  and  8  storage  registers (x8...x15)  are  included  for  this
purpose. The stack top (x0=x) may be used as  x in command files. The
calculator operates in reverse polish notation,  i.e.  operations  are
performed on the stack, unless the operand is given with the command.

REAdx [c]                read a number from the current line into x0

                         c   is  the column of  the  rightmost  digit,
                         default is column 1

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.

                         The leftmost digit is determined by the first
                         character left of c,  that is neither a digit
                         nor  one of '.',  ',' or '-'  (point,  komma,
                         minus)

                         a stacklift is performed, and x7 is discarded

WRItex [c]               write  x0 into the  current  line,  rightmost
                         digit at column c

                         * for c  means the position of the cursor, if
                         it is in the data window, or the first column
                         in the display window otherwise. '*+c' or '*-
                         c' may be used to define a position  relative
                         to '*'.  If c  is omitted, x is left adjusted
                         to column 1.

PUsh [n]                 set x0 = n

                         if n  is omitted, x is pushed on the stack

                         a stacklift is performed, and x7 is discarded

POp                      x0  is popped from the stack,  the  stack  is
                         lowered, and x7 is doubled to x7 and x6

STOre [n]                set xn  = x0

                         default for n  is 1, * means 8 (first storage
                         register)

RECall [n]               set x0 = xn

                         default for n  is 1, * means 8 (first storage
                         register)

                         a stacklift is performed, and x7 is discarded

                         RECALL 7 is equivalent to a stack roll-up

PLUs [n]                 if a number n  is given, do:  x0 = x0 + n.

                         else do:   x0 = x1 + x0,  and lower the stack
                         (i.e. x1 = x2, x2 = x3 etc.)

MINus [n]                if a number n  is given, do:  x0 = x0 - n.

                         else do:   x0 = x1 - x0,  and lower the stack
                         (i.e. x1 = x2, x2 = x3 etc.)

MULtiply [n]             if a number n  is given, do:  x0 = x0 * n.

                         else do:   x0 = x1 * x0,  and lower the stack
                         (i.e. x1 = x2, x2 = x3 etc.)

DIVide [n]               if a number n  is given, do:  x0 = x0 / n.

                         else do:   x0 = x1 / x0,  and lower the stack
                         (i.e. x1 = x2, x2 = x3 etc.)

MODulo [n]               if a number n  is given, do:  x0 = x0 mod n.

                         else do:  x0 = x1 mod x0, and lower the stack
                         (i.e. x1 = x2, x2 = x3 etc.)

IFZero ...;              execute  ...  if  x0 = 0  (may  also  be  the
                         commentchar,  in  which case the rest of  the
                         line is ignored if x0 = 0)


IFPos ...;               execute  ...  if  x0 > 0  (may  also  be  the
                         commentchar,  in  which case the rest of  the
                         line is ignored if x0 > 0)



Commands for Experts

COMPRess                 compress file in storage

                         This  is usually done automatically,  if  the
                         unused space has blown up to 50kB,  and  half
                         of  the available memory has  been  used.  In
                         some cases, however, e.g. before a large copy
                         (thousands of lines) it is advisable to force
                         a compress by the COMPRESS command.

ESCapechar [c]           define c  as new escape character, to be used
                         in WEX files for argument labelling

                         if c  is omitted,  the current escape charac-
                         ter  is  displayed,  which is  initially  the
                         ASCII escape x'1B' (^[ or ^;)

                         NOTE:  Do  not  change the  escape  character
                         permanently under any circumstances!  But  if
                         you  do,  make sure that the old one  is  not
                         used in any WEX files you will use.

CLS                      clear screen (leave fullscreen mode)

SETSAVed                 set the current workfile's "saved" flag

                         The "saved" mark (.) will appear in the upper
                         right corner,  and the program behaves as  if
                         the file would have been saved,  e.g.  a QUIT
                         or LOAD will be accepted even if the file has
                         been changed.

WFW                      switch  to  workfile  3,  which  is  used  to
                         execute WEX-files

                         Switch back with the WFILE command.

... ONERRor [command];   on  error clear  commandline,  reset  message
                         line, and execute command

                         command  may be empty (just clear commandline
                         and  error message),  or may be  the  comment
                         character preceded by a blank (ignore rest of
                         line in case of error)

                         This  must  follow the last  parameter  of  a
                         command,  and no text-style parameter must be
                         omitted before it (to be used in a WEX file).

COMMAND INDEX

COMMAND.........CHAPTER........................

Add             Editing Commands: Line Changing
ALL             Editing Commands: Finding
APpend          Editing Commands: Text Changing

BBegin          Block Commands
BCopy           Block Commands
BDELete         Block Commands
BELl            General Commands
BEnd            Block Commands
Bottom          Editing Commands: Moving Around
BRESet          Editing Commands: Line Changing

CAll            General Commands
CASe            Editing Commands: Finding
CDir            File Handling Commands
CDELete         Editing Commands: Text Changing
CDUpl           Editing Commands: Text Changing
Change          Editing Commands: Text Changing
CInsert         Editing Commands: Text Changing
CLS             Commands for Experts
CLICk           Screen Commands
CMAtch          Editing Commands: Finding
CMPare          Editing Commands: Finding
COMMEntchar     General Commands
COMPRess        Commands for Experts
COPy            Editing Commands: Line Changing
CPAth           General Commands
CPOint          Editing Commands: Finding
CURsor          Screen Commands

DELete          Editing Commands: Line Changing
DIR             File Handling Commands
DIVide          Calculator Commands
Down            Editing Commands: Moving Around

ERAse           File Handling Commands
ESCapechar      Commands for Experts
EXCLude         Editing Commands: Finding
EXECLine        General Commands
EXecute         General Commands
EXECWfw         General Commands

Find            Editing Commands: Finding
FLip#           Editing Commands: Moving Around
FName           General Commands

Get             File Handling Commands
GO              General Commands

IFPos           Calculator Commands
IFZero          Calculator Commands
INVert          Screen Commands
Insert          Editing Commands: Line Changing

LEft            Editing Commands: Moving Around
LOad            File Handling Commands
Locate          Editing Commands: Finding
LOWercase       Editing Commands: Text Changing

MArk            Editing Commands: Moving Around
MDir            File Handling Commands
MINus           Calculator Commands
MODulo          Calculator Commands
Move            Editing Commands: Line Changing
MULtiply        Calculator Commands

Next            Editing Commands: Moving Around
NPoint          Editing Commands: Finding
NFind           Editing Commands: Finding
NRPoint         Editing Commands: Finding

... ONERRor     Commands for Experts
OR              Editing Commands: Text Changing
OVerlay         Editing Commands: Text Changing

PAd             Screen Commands
PATH            File Handling Commands
PCursor         Editing Commands: Moving Around
PFkey           General Commands
PLUs            Calculator Commands
Point           Editing Commands: Finding
POP             Calculator Commands
PUsh            Calculator Commands
PUT             File Handling Commands
PUTD            File Handling Commands

Query           General Commands
QQuit           General Commands
QUit            General Commands

REAdx           Calculator Commands
RECall          Calculator Commands
REName          File Handling Commands
RESET           File Handling Commands
Reshow          General Commands
RIght           Editing Commands: Moving Around
RIGHTLeft       Editing Commands: Moving Around
RLocate         Editing Commands: Finding
RNPoint         Editing Commands: Finding
RPoint          Editing Commands: Finding
RReshow         General Commands

SAVe            File Handling Commands
Setbot          General Commands
SETSAVed        General Commands
SOrt            Editing Commands: Line Changing
SPLtjoin        Editing Commands: Text Changing
SSAve           File Handling Commands
STOre           Calculator Commands
SYNonym         General Commands

TABEXpand       Editing Commands: Text Changing
TAbset          Screen Commands
Terminate       Editing Commands: Finding
TOP             Editing Commands: Moving Around
TRIm            Editing Commands: Text Changing
TRUncate        Editing Commands: Text Changing

UNDoubl         Editing Commands: Text Changing
Up              Editing Commands: Moving Around
UPPercase       Editing Commands: Text Changing

WAIt            General Commands
Wfile           Editing Commands: Moving Around
WFW             Commands for Experts
WILDcard        Editing Commands: Finding
WRItex          Calculator Commands

Zone            Editing Commands: Finding

-               Editing Commands: Moving Around
-/              Editing Commands: Finding
+               Editing Commands: Moving Around
=               General Commands
:               Editing Commands: Moving Around
;               separator character
/               Editing Commands: Finding
{               comment character
@               General Commands
#               Editing Commands: Moving Around

WEX Files

Some  special  WEX files,  partly used in  combination  with  external
programs,  are  discussed  below.  Some  of them use  workfile  2  for
temporary data (as some commands do), so you should use only workfiles
0 and 1 for editing.


CL program type libs

This is an example using a WEX file to compile and link a program.  It
is  set up for the MEGAMAX C compiler (1.1),  and  includes  compiler,
code  improver  and  linker calls.  The source  is  expected  in  file
program.C,  and will be linked into program.type,  where type  is TOS,
TTP or PRG. If omitted, the default is TOS.

libs   is  a string containing additional .O and library files  to  be
included in the linker call, e.g. 'SUBPRG1.O PRG2.O MYLIB.L DOUBLE.L'.


EXTRACT string [mode]

Copy all lines with string  from current workfile (0 or 1) to workfile
2.  A mode  I (ignore) or R (respect) may be given, like for the POINT
command.


PROFILE

Sample profile, which is automatically executed when WEDIT is invoked.


SUM column

Sum  up  the  column of numbers (rightmost digit  column  given)  from
current  line until nothing or 0 can be read,  and write sum one  line
below.



Synonyms Defined in the Standard Profile

ATALL search-item 'commands'

Execute commands  at every search-item  found with the CPOINT  command
in IGNORE mode after the current line.  For example you can delete the
next five characters after every '$' with: ATALL $ 'CDEL *+1 +4'.


CLEAR

Reset only the current workfile


CP source target options mindate

file copy; same as @FCOPY 'source target options mindate', see below


LC path

This is an improved DIR ("list catalog") command.  It invokes DIR  and
sorts by date, latest date on top.


FREN oldname newname

This is an alternative rename;  in contrast to the RENAME command, the
path  for newname  is taken from oldname,   not from the current  path
(this does not work with wildcards).


FT type

Change type (extension) in the name of the current file. Example:
 FT bak
will change the filename to 'name.BAK'


HELP name

This adds a help feature to WEDIT.  It loads a file name.HLP from  the
current  CPATH\help\  into  workfile 2.  'HELP  COMMANDS'  displays  a
command  list.  A simple 'HELP' will invoke 'HELP  COMMANDS',  if  the
COMMANDS.HLP file is the first file in the help subdirectory  (can  be
checked with DIR without sorting). You may add more HLP files for your
own WEX commands, if desired.


REPEAT n; commandline

Repeat commandline  n times. Example:
 REPEAT 12; COPY 2
will  add the current and next line 12 times successively to the  copy
buffer.


X 'commandline'

Execute  commandline.  This has the advantage,  that escape-codes  are
resolved.  Example:  X  'RENAME  F C:\f'   will move  the  currently
edited file to the root directory (assuming it is in a subdirectory of
C:). Another example:
 X CH 33 item .
will  change  all 'itemitem' to 'item' ('item' is  the  3rd  argument,
hence 3).
 X SAVE cn.SAV
will  save  the current file in the control path (defined  by  CPATH),
under its own filename and extension SAV.


XTAB

expand tabs in a file with standard tab positions (every 8 columns, at
1, 9, 17, 33...)


UTAB

same as XTAB, but first tab stop is at column 8 (8, 16, 32...)


External Programs

@COMP filea fileb        compare filea  with fileb

                         the output is written to file COMP.$W$, which
                         contains the text starting in column 5 and  a
                         flag in columns 1...4:

                                        identical line
                         +++            line added in fileb
                         ---            line deleted in fileb


@FCOPY 'source [target [[-][p][f][t][a][i][o...][l...] [mindate]]]'
                         copy file(s) from source  to target

                         source   may be a single filename  (including
                         an  optional path) or a  template  containing
                         the wildcards '*' and '?'

                         target   may be a single filename  (including
                         an  optional path) or a  template  containing
                         the  wildcards '*' and '?',  or just  a  path
                         followed by a backslash '\'

                         If target  is just a drive letter followed by
                         a colon ':',  the default path of this  drive
                         is used.  If target  is omitted,  the current
                         path is used.

                         Existing target files are overwritten without
                         warning

                         Options (may also be capital letters) must be
                         concatenated to one string:

                         p              show  files and  prompt:  Only
                                        files acknowledged by 'y'  are
                                        copied.

                         ?              same as p

                         f              floppy change: wait for floppy
                                        change between read and write.
                                        This allows copying from A: to
                                        A:   between   two   different
                                        floppies. If you have only one
                                        drive, never use B: !

                         t              don't   copy  timestamp   from
                                        source to target;  use  actual
                                        date.

                         a              append to output file  instead
                                        of replacing it

                         i              indirect  copy:  source  is  a
                                        name  of a file with one  line
                                        for  each  file  or  group  of
                                        files  to be  copied,  of  the
                                        form

                                        source1        target1
                                        source2        target2
                                        etc.

                                        this  file  should be  on  the
                                        volume   which  contains   the
                                        source  files,  when  the  'f'
                                        option is used

                         on             start copying n  bytes  offset
                                        at  each file  (shorter  files
                                        are  ignored,   default  is  0
                                        bytes offset)

                         ln             copy at most n  bytes per file
                                        (default is all bytes)

                         mindate  is the minimum date in the directory
                         timestamp  for a file to be  copied,  in  the
                         format YYMMDD.


@FORMAT '[-][a|b][x][1|2][+ ...]'
                         format floppy disk

                         options (may also be capital letters), conca-
                         tenated to one string:

                         a              drive A: (default)

                         b              drive B:

                         x              10 sectors per track  (default
                                        is 9)

                         1              1 sided

                         2              2 sided (default)

                         +              one more extra track  (default
                                        is  80 tracks) for each +  (81
                                        is  save,  some  drives  allow
                                        even 83)


@TOUCH 'file [yymmdd] [+attr] [-attr]'
                         change file's timestamp and/or attributes

                         file   is any valid path/file name,  and  may
                         also  consist  of wildcards '*'  and  '?'  to
                         denote a group of files to be touched

                         yymmdd  is the new date of the file,  default
                         is current date; time is always current time

                         attr  is a string of any of
                         R = read-only
                         C = closed/written
                         H = hidden
                         S = system
                         a  string +attr  will set  the  corresponding
                         flag, a string -attr  will reset it

                         If a +/- attributes string is given, the date
                         will  be left unchanged,  unless  yymmdd   is
                         given explicitely.  If no argument is  given,
                         the  files  are  stamped  with  the   current
                         date/time.


@VOL 'drive [-|+|newname]'
                         show/modify  volume label and volume  parame-
                         ters.

                         drive  is a drive letter (small or  capital).
                         If follwed by a '/',  VOL is executed without
                         the final prompt for a keypress.

                         - signals deletion of the volume label. After
                         deleting GEMDOS buffers are reinitialised  by
                         simulating a media change.

                         + nothing is changed on the disk,  but GEMDOS
                         is reinitialised for the drive.

                         newname  is a new volume name to be  created.
                         An existing old volume name is  deleted,  and
                         GEMDOS is reinitialised.


The DEFAULT.PAD Key Assignments

Help            [Enter]                                   enter
SHFT-Help       [Enter]                                   enter
CTRL-Help       [Home] [ALT-Del] HELP [ ]                 HELP ...
                shortcut for 'HELP ' in the command-line
Return          [SHFT-CR]                                 (return)
                cursor to start of next screen line (number field)
CTRL-keypad-0   [6 * CTRL-+] [Home] pre0 [Esc] [Enter]    prefix off
                prefix off & adjust column counter
CTRL-keypad-1   [SHFT-CR] [Up] i [Enter]                  add line
                add new line after cursor line
CTRL-keypad-2   [Up] [Left] [CTRL-Left] [Down]            tabular left
CTRL-keypad-3   [Up] [Rght] [CTRL-Rght] [Down]            tabular
                move  right and left in a table,  as determind by  the
                previous line
CTRL-keypad-4   [CTRL-Left] [F2] [Down] [CTRL keypad-)]   linewrap
                move last word to new line,  to continue  input,  when
                the warning tone at end of line has been sound  during
                typing,  and the started word is too long to  continue
                on  the  current  line.  This work oly if  key  F2  is
                assigned "SPLTJOIN *" as in the default PROFILE.
CTRL-keypad-5   [SHFT-CR] [keypad-)]                      newline
                cursor to start of next data field
CTRL-keypad-6   [SHFT-CR] [keypad-)] [CTRL keypad-)]      newline-end
                cursor to end of next data field
CTRL-keypad-7   [CTRL-Ins] [ ] [Left] [ALT-Esc]           insblank
                insert a blank and switch insert mode off
CTRL-keypad-8   [SHFT-CR] [keypad-(] [keypad-(] [keypad-(]
                cursor to start of previous line
CTRL-keypad-9   [SHFT-CR] [keypad-(] [keypad-(] [keypad-(]
                [CTRL keypad-)]
                cursor to end of previous line
CTRL-keypad-.   [6 * CTRL-keypad--] [Home] pre [Esc] [Enter]
                invert CTRL-keypad-0: prefix on

keypad-. and 0-9 are unassigned, i.e. they act as .,0-9 characters



MAKING YOUR OWN WEX FILES

Doing  more  with WEX files than a simple  command  sequence  requires
knowledge  about  WEDIT's command processing.   A command  file  is  a
special  workfile  with number 3,  which can be accessed via  the  WFW
command.  Any  manipulations,  like parameter  substitutions,  setting
defaults, jumping within the command file etc. are just simple editing
processes,  as  string  changes and string searches.  Once  you  start
thinking  in terms of an editor instead of in terms of  a  programming
language,  you  will find that almost everything can be done  in  this
way, just a little bit different from usual 'command languages'.

There  are  pretty  much examples in the PF  key  definitions  of  the
standard PROFILE.WEX.

All  occurrences  of the escape character followed  immediately  by  a
digit 1 through 9,  or one of the letters 'c d F f n P p t w x' in the
workfile 3 (from the current line to the end) will be substituted with
the  actual  values  upon invocation.  Recursive use  of  the  escape-
sequences is possible; the evaluation sequence is 1-2-3-4-5-6-7-8-9-f-
n-t-F-P-c-p-w-d-x.  If you need delayed substitution,  e.g. to account
for  changes in the workfile number,  file name or x0 stack  register,
you have to switch the escape character and use the 'EXECWFW'  command
when these values are defined.

Note  also,  that only the first 75 characters in each line of  a  WEX
file  are used as command line.  Parameter substitution  resulting  in
lines with more than 75 characters may result in incorrect  operation.
If you are uncertain about parameter length, it may be wise to use the
'?' for separate read-in of parameter strings.

Execution may be stopped between commands by pressing CTRL-C (^C).  It
may be resumed at the next command by pressing ENTER after the prompt.

While debugging WEX files,  use the statement 'WFW' after the 'EXECUTE
...' in the commandline.  You may resume an interrupted execution with
the 'EXECUTE *' command in workfile 3.


                                 ***
